@@ -19,7 +19,8 @@
 #' install_bitbucket("sulab/mygene.r@@default")
 #' install_bitbucket("dannavarro/lsr-package")
 #' }
-install_bitbucket <- function(repo, username, ref = "master", subdir = NULL,
+install_bitbucket <- function(repo, username, ref = "master",
+                              subdir = NULL, quiet = FALSE,
                               auth_user = NULL, password = NULL, ...) {
 
   remotes <- lapply(repo, bitbucket_remote, username = username, ref = ref,
