@@ -5,13 +5,8 @@ compile_rcpp_attributes <- function(pkg) {
 
   # Only scan for attributes in packages explicitly linking to Rcpp
   if (links_to_rcpp(pkg)) {
-
-    if (!requireNamespace("Rcpp", quietly = TRUE))
-      stop("Rcpp required for building this package")
-
-    # Only compile attributes if we know we have the function available
-    if (utils::packageVersion("Rcpp") >= "0.10.0")
-      Rcpp::compileAttributes(pkg$path)
+    check_suggested("Rcpp")
+    Rcpp::compileAttributes(pkg$path)
   }
 }
 
